@@ -3,18 +3,7 @@ import hmac
 import json
 
 import arivo
-
-
-class WebhookError(Exception):
-    pass
-
-
-class InvalidSignature(WebhookError):
-    pass
-
-
-class InvalidPayload(WebhookError):
-    pass
+from .errors import *
 
 
 class Event(dict):
@@ -39,9 +28,6 @@ def verify_signature(payload, signature, secret=None):
     if hasattr(secret, "encode"):
         secret = secret.encode()
 
-    if signature is None or secret is None:
-        raise InvalidSignature()
-
     compare_signature = hmac.new(secret, payload, hashlib.sha256).hexdigest()
     if not hmac.compare_digest(signature, compare_signature):
         raise InvalidSignature()
